@@ -25,8 +25,8 @@ couchTests.reduce_false = function(debug) {
     _id:"_design/test",
     language: "javascript",
     views: {
-      summate: {map:"function (doc) {emit(doc.integer, doc.integer)};",
-                reduce:"function (keys, values) { return sum(values); };"},
+      summate: {map:"function (doc) { emit(doc.integer, doc.integer); }",
+                reduce:"function (keys, values) { return sum(values); }"},
     }
   };
   T(db.save(designDoc).ok);
@@ -38,8 +38,7 @@ couchTests.reduce_false = function(debug) {
   //Test that we get our docs back
   res = db.view('test/summate', {reduce: false});
   T(res.rows.length == 5);
-  for(var i=0; i<5; i++)
-  {
+  for(var i=0; i<5; i++) {
     T(res.rows[i].value == i+1);
   }
 };
