@@ -69,7 +69,7 @@ couchTests.security_validation = function(debug) {
       var designDoc = {
         _id:"_design/test",
         language: "javascript",
-        validate_doc_update: "(" + (function (newDoc, oldDoc, userCtx, secObj) {
+        validate_doc_update: stringFun(function (newDoc, oldDoc, userCtx, secObj) {
           if (secObj.admin_override) {
             if (userCtx.roles.indexOf('_admin') != -1) {
               // user is admin, they can do anything
@@ -85,7 +85,7 @@ couchTests.security_validation = function(debug) {
               throw {unauthorized:
                   "You are not the author of this document. You jerk."};
           }
-        }).toString() + ")"
+        })
       }
 
       // Save a document normally
@@ -250,16 +250,16 @@ couchTests.security_validation = function(debug) {
           target:"test_suite_db_b"},
 
         {source:"test_suite_db_a",
-          target:{url: "http://" + host + "/test_suite_db_b",
+          target:{url: CouchDB.protocol + host + "/test_suite_db_b",
                   headers: AuthHeaders}},
 
-        {source:{url:"http://" + host + "/test_suite_db_a",
+        {source:{url:CouchDB.protocol + host + "/test_suite_db_a",
                  headers: AuthHeaders},
           target:"test_suite_db_b"},
 
-        {source:{url:"http://" + host + "/test_suite_db_a",
+        {source:{url:CouchDB.protocol + host + "/test_suite_db_a",
                  headers: AuthHeaders},
-         target:{url:"http://" + host + "/test_suite_db_b",
+         target:{url:CouchDB.protocol + host + "/test_suite_db_b",
                  headers: AuthHeaders}},
       ]
       var adminDbA = new CouchDB("test_suite_db_a", {"X-Couch-Full-Commit":"false"});
